#include <gtk/gtk.h>
#include <unistd.h>
#include <fcntl.h>
#include <cairo.h>

#define PROGRAM_NAME "Armadillo-440 png display"
#define DEFAULT_XRES (480)
#define DEFAULT_YRES (272)

#define ARRAY_SIZE(array) sizeof(array)/sizeof(array[0])

#define TEMPORARY_DIR "/tmp/"
#define PIC_IMG TEMPORARY_DIR "a440_480x272.png"

GtkWidget *window;

static gboolean picture_expose_event(GtkWidget *widget, GdkEventExpose *event,
				 gpointer data)
{
	static cairo_surface_t *bg;
	cairo_t *cr;

	bg = cairo_image_surface_create_from_png(PIC_IMG);

	cr = gdk_cairo_create(widget->window);

	cairo_set_source_surface(cr, bg, 0, 0);
	cairo_paint(cr);
	cairo_destroy(cr);

	return TRUE;
}

static void window_setup(void)
{
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);

	gtk_window_set_title(GTK_WINDOW(window), PROGRAM_NAME);
	gtk_container_set_border_width(GTK_CONTAINER(window), 0);
	gtk_window_set_default_size(GTK_WINDOW(window),
				    DEFAULT_XRES, DEFAULT_YRES);
}

int main(int argc, char *argv[])
{
	GtkWidget *main_box, *draw_area;

/*** add: hide cursor: begin ***/
	GdkCursor *transparent_cursor;
	gchar blank_bits[32] = {[0 ... 31] = 0};
	GdkPixmap *blank_bitmap;
	GdkColor color_black = {0, 0, 0, 0};
/*** add: hide cursor: end ***/

	gtk_init(&argc, &argv);

	window_setup();

/*** add: hide cursor: begin ***/
	blank_bitmap = gdk_bitmap_create_from_data(NULL, blank_bits, 16, 16);
	transparent_cursor = gdk_cursor_new_from_pixmap(blank_bitmap, blank_bitmap, &color_black, &color_black, 8, 8);
	gdk_pixmap_unref(blank_bitmap);
	gdk_window_set_cursor(gtk_widget_get_root_window(window), transparent_cursor);
/*** add: hide cursor: end ***/

	main_box = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), main_box);

	draw_area = gtk_drawing_area_new();

	gtk_box_pack_start(GTK_BOX(main_box), draw_area, TRUE, TRUE, 0);

	g_signal_connect(G_OBJECT(draw_area), "expose-event",
			 G_CALLBACK(picture_expose_event), NULL);

	gtk_widget_show_all(main_box);

	gtk_widget_show(window);

	gtk_main();

	return 0;
}
